###### R scripts for Forests manuscript ###########
rm(list = ls())
setwd("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Files/")

##  Load required packages
library("plyr", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("vegan", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("corrplot", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("ggplot2", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("Hmisc", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("PMCMR", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("reshape2", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")
library("phyloseq", lib.loc="/Library/Frameworks/R.framework/Versions/3.4/Resources/library")

stderr <- function(x) sd(x)/sqrt(length(x))

# Read in the data
##  ALLDATA.txt were made using normalized biom file absolute abundance values
##  ALLDATA_Final.txt = removed sites with no non-ash plots
##  ALLDATA_Final_AC3.txt = removed sites with AC>3 and all sites that don't have both ash and non-ash plots

ALLDATA<-read.delim("ALLDATA_Final.txt")

## For analysis of "healthy ash" sites, use this file instead.
# ALLDATA<-read.delim("ALLDATA_Final_AC3.txt")

ash <- ALLDATA[ALLDATA$AvNA_ == "Ash",]
nonash <- ALLDATA[ALLDATA$AvNA_ == "NonAsh",]

###  Create a dataframe with only bacteria abundance
dfbac<-data.frame(ALLDATA[,29:72])
#  10 most abundant bacterial phyla (98% of total)
dfbac10<-data.frame(ALLDATA[,29:38])

# Gene abundance data (in proportions)
dfgenes<-data.frame(ALLDATA[,73:96])

# Environmental data
dfenv<-data.frame(ALLDATA[2:28])

# Make 0 = NA for AC and PercAsh
dfenvNA<-data.frame(ALLDATA[2:28])
dfenvNA[dfenvNA == 0]<- NA

# Make NA = 1 for AC
dfenv1 <- dfenvNA
dfenv1[,2][is.na(dfenv1[,2])] <- 1
dfenv1[,5:27][is.na(dfenv1[,5:27])] <- 0
rm(dfenvNA)

#  Bacteria data
#  Transform the dataset
dfbac.hel<-decostand(dfbac,"hellinger")
dfbac10.hel<-decostand(dfbac10,"hellinger")

#  Combine data
ALLDATA.hel <- cbind(dfenv1,dfbac.hel,dfgenes)
  
# Create subsets of explanatory variables
dfenv1_soil <- dfenv1[, c(11,13:27)]

###  Make dissimilarity matrices
bacBray.hel <- vegdist(dfbac.hel)
soilEuclid <- vegdist(scale(dfenv1_soil), "euclid")
geneBray <- vegdist(dfgenes)

################    Adonis tests   ###############
###  Effects of Ash v Non-ash plots and Site on Bacterial community structure and overall soil environment
attach(ALLDATA.hel)

anova(betadisper(soilEuclid,AvNA_))
(adonis(soilEuclid~AvNA_, permutations = 99999))

anova(betadisper(soilEuclid,Site_))
(adonis(soilEuclid~Site_, permutations = 99999))

anova(betadisper(bacBray.hel,AvNA_))
(adonis(bacBray.hel~AvNA_, permutations = 99999))

anova(betadisper(bacBray.hel,Site_))
(adonis(bacBray.hel~Site_, permutations = 99999))


##############################################
########## Ash vs NonAsh Stats ###############

## All variables
attach(ALLDATA.hel)

plot(MeanAC~AvNA_)
bartlett.test(MeanAC~AvNA_)  
shapiro.test(MeanAC)
wilcox.test(MeanAC~AvNA_)

plot(BA~AvNA_)
bartlett.test(BA~AvNA_)  
shapiro.test(BA)
wilcox.test(BA~AvNA_) 

plot(Stems~AvNA_)
bartlett.test(Stems~AvNA_)  
shapiro.test(Stems)  
wilcox.test(Stems~AvNA_)

plot(Perc_Maple~AvNA_)
bartlett.test(Perc_Maple~AvNA_)  
shapiro.test(Perc_Maple)  
wilcox.test(Perc_Maple~AvNA_)

plot(Perc_Oak~AvNA_)
bartlett.test(Perc_Oak~AvNA_)  
shapiro.test(Perc_Oak)  
wilcox.test(Perc_Oak~AvNA_)

plot(Perc_Beech~AvNA_)
bartlett.test(Perc_Beech~AvNA_)  
shapiro.test(Perc_Beech)  
wilcox.test(Perc_Beech~AvNA_)

plot(Perc_Hickory~AvNA_)
bartlett.test(Perc_Hickory~AvNA_)  
shapiro.test(Perc_Hickory)  
wilcox.test(Perc_Hickory~AvNA_)

plot(pH~AvNA_)
bartlett.test(pH~AvNA_)  
shapiro.test(pH) 
wilcox.test(pH~AvNA_)

plot(C~AvNA_)
bartlett.test(C~AvNA_)  
shapiro.test(C)
wilcox.test(C~AvNA_)

plot(N~AvNA_)
bartlett.test(N~AvNA_)  
shapiro.test(N)
wilcox.test(N~AvNA_) 

plot(CN~AvNA_)
bartlett.test(CN~AvNA_)  
shapiro.test(CN)
wilcox.test(CN~AvNA_) 

plot(Ca~AvNA_)
bartlett.test(Ca~AvNA_)  
shapiro.test(Ca)
wilcox.test(Ca~AvNA_) 

plot(K~AvNA_)
bartlett.test(K~AvNA_)  
shapiro.test(K)
wilcox.test(K~AvNA_) 

plot(P~AvNA_)
bartlett.test(P~AvNA_)  
shapiro.test(P)
wilcox.test(P~AvNA_) 

plot(Mg~AvNA_) 
bartlett.test(Mg~AvNA_)  
shapiro.test(Mg)
wilcox.test(Mg~AvNA_)

plot(Al~AvNA_)
bartlett.test(Al~AvNA_)  
shapiro.test(Al)
wilcox.test(Al~AvNA_) 

plot(B~AvNA_)
bartlett.test(B~AvNA_)  
shapiro.test(B)
wilcox.test(B~AvNA_) 

plot(Cu~AvNA_)
bartlett.test(Cu~AvNA_)  
shapiro.test(Cu)
wilcox.test(Cu~AvNA_) 

plot(Fe~AvNA_)
bartlett.test(Fe~AvNA_)  
shapiro.test(Fe)
wilcox.test(Fe~AvNA_) 

plot(Mn~AvNA_)
bartlett.test(Mn~AvNA_)  
shapiro.test(Mn)
wilcox.test(Mn~AvNA_) 

plot(Na~AvNA_)
bartlett.test(Na~AvNA_)  
shapiro.test(Na)
wilcox.test(Na~AvNA_) 

plot(S~AvNA_)
bartlett.test(S~AvNA_)  
shapiro.test(S)
wilcox.test(S~AvNA_)

plot(Zn~AvNA_)
bartlett.test(Zn~AvNA_)  
shapiro.test(Zn)
wilcox.test(Zn~AvNA_)


##### Bacterial abundance AvNA
attach(ALLDATA.hel)
plot(Acidobacteria~AvNA_)
bartlett.test(Acidobacteria~AvNA_)  
shapiro.test(Acidobacteria)
wilcox.test(Acidobacteria~AvNA_) 

plot(Verrucomicrobia~AvNA_)
bartlett.test(Verrucomicrobia~AvNA_)  
shapiro.test(Verrucomicrobia)
wilcox.test(Verrucomicrobia~AvNA_) 

plot(Proteobacteria~AvNA_)
bartlett.test(Proteobacteria~AvNA_)  
shapiro.test(Proteobacteria)
wilcox.test(Proteobacteria~AvNA_)

plot(Bacteroidetes~AvNA_)
bartlett.test(Bacteroidetes~AvNA_)  
shapiro.test(Bacteroidetes)
wilcox.test(Bacteroidetes~AvNA_)

plot(Planctomycetes~AvNA_)
bartlett.test(Planctomycetes~AvNA_)  
shapiro.test(Planctomycetes)
wilcox.test(Planctomycetes~AvNA_)

plot(Nitrospirae~AvNA_)
bartlett.test(Nitrospirae~AvNA_)  
shapiro.test(Nitrospirae)
wilcox.test(Nitrospirae~AvNA_) 

plot(Actinobacteria~AvNA_)
bartlett.test(Actinobacteria~AvNA_)  
shapiro.test(Actinobacteria)
wilcox.test(Actinobacteria~AvNA_)

plot(Elusimicrobia~AvNA_)
bartlett.test(Elusimicrobia~AvNA_)  
shapiro.test(Elusimicrobia)
wilcox.test(Elusimicrobia~AvNA_) 

plot(Crenarchaeota~AvNA_)
bartlett.test(Crenarchaeota~AvNA_)  
shapiro.test(Crenarchaeota)
wilcox.test(Crenarchaeota~AvNA_) 

plot(Chloroflexi~AvNA_)
bartlett.test(Chloroflexi~AvNA_)  
shapiro.test(Chloroflexi)
wilcox.test(Chloroflexi~AvNA_) 

########## Statistics for 20 most abundant bacterial classes

ALLDATA_L3 <- read.delim("ALLDATA_L3_Final.txt")
dfbacL3<-data.frame(ALLDATA_L3[,25:174])
dfbacL3.hel<-decostand(dfbacL3,"hellinger")

ALLDATA_L3.hel <- cbind(dfenv1,dfbacL3.hel,dfgenes)

attach(ALLDATA_L3.hel)

plot(Verrucomicrobia_Spartobacteria~AvNA_)
wilcox.test(Verrucomicrobia_Spartobacteria~AvNA_) 

plot(Acidobacteria_Acidobacteriia~AvNA_)
wilcox.test(Acidobacteria_Acidobacteriia~AvNA_) 

plot(Acidobacteria_DA052~AvNA_)
wilcox.test(Acidobacteria_DA052~AvNA_) 

plot(Proteobacteria_Deltaproteobacteria~AvNA_)
wilcox.test(Proteobacteria_Deltaproteobacteria~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria~AvNA_)  

plot(Acidobacteria_Acidobacteria.6~AvNA_)
wilcox.test(Acidobacteria_Acidobacteria.6~AvNA_) 

plot(Acidobacteria_Solibacteres~AvNA_)
wilcox.test(Acidobacteria_Solibacteres~AvNA_)  

plot(Verrucomicrobia_Pedosphaerae~AvNA_)
wilcox.test(Verrucomicrobia_Pedosphaerae~AvNA_)  

plot(Proteobacteria_Gammaproteobacteria~AvNA_)
wilcox.test(Proteobacteria_Gammaproteobacteria~AvNA_)

plot(Bacteroidetes_Saprospirae~AvNA_)
wilcox.test(Bacteroidetes_Saprospirae~AvNA_) 

plot(Proteobacteria_Betaproteobacteria~AvNA_)
wilcox.test(Proteobacteria_Betaproteobacteria~AvNA_) 

plot(Nitrospirae_Nitrospira~AvNA_)
wilcox.test(Nitrospirae_Nitrospira~AvNA_)  

plot(Planctomycetes_Planctomycetia~AvNA_)
wilcox.test(Planctomycetes_Planctomycetia~AvNA_) 

plot(Acidobacteria_Chloracidobacteria~AvNA_)
wilcox.test(Acidobacteria_Chloracidobacteria~AvNA_) 

plot(Planctomycetes_Phycisphaerae~AvNA_)
wilcox.test(Planctomycetes_Phycisphaerae~AvNA_)

plot(Actinobacteria_Thermoleophilia~AvNA_)
wilcox.test(Actinobacteria_Thermoleophilia~AvNA_) ##  * W = 81, p-value = 0.0159 

plot(Elusimicrobia_Elusimicrobia~AvNA_)
wilcox.test(Elusimicrobia_Elusimicrobia~AvNA_) 

plot(Acidobacteria_Acidobacteria5~AvNA_)
wilcox.test(Acidobacteria_Acidobacteria5~AvNA_)  

plot(Crenarchaeota_Thaumarchaeota~AvNA_)
wilcox.test(Crenarchaeota_Thaumarchaeota~AvNA_)

plot(Actinobacteria_Actinobacteria~AvNA_)
wilcox.test(Actinobacteria_Actinobacteria~AvNA_)  ## *  W = 76, p-value = 0.04645


########## Statistics for 30 most abundant bacterial orders (Wilcoxon only)
ALLDATA_L4 <- read.delim("ALLDATA_L4_Final.txt")
dfbacL4<-data.frame(ALLDATA_L4[,25:319])
dfbacL4.hel<-decostand(dfbacL4,"hellinger")

ALLDATA_L4.hel <- cbind(dfenv,dfbacL4.hel,dfgenes)

attach(ALLDATA_L4.hel)

plot(Verrucomicrobia_Spartobacteria_Chthoniobacterales~AvNA_)
wilcox.test(Verrucomicrobia_Spartobacteria_Chthoniobacterales~AvNA_) 

plot(Acidobacteria_Acidobacteriia_Acidobacteriales~AvNA_)
wilcox.test(Acidobacteria_Acidobacteriia_Acidobacteriales~AvNA_)

plot(Acidobacteria_DA052_Ellin6513~AvNA_)
wilcox.test(Acidobacteria_DA052_Ellin6513~AvNA_) 

plot(Acidobacteria_Acidobacteria.6_iii1.15~AvNA_)
wilcox.test(Acidobacteria_Acidobacteria.6_iii1.15~AvNA_) 

plot(Acidobacteria_Solibacteres_Solibacterales~AvNA_)
wilcox.test(Acidobacteria_Solibacteres_Solibacterales~AvNA_)

plot(Verrucomicrobia_Pedosphaerae_Pedosphaerales~AvNA_)
wilcox.test(Verrucomicrobia_Pedosphaerae_Pedosphaerales~AvNA_) 

plot(Proteobacteria_Deltaproteobacteria_Syntrophobacterales~AvNA_)
wilcox.test(Proteobacteria_Deltaproteobacteria_Syntrophobacterales~AvNA_) 

plot(Bacteroidetes_Saprospirae_Saprospirales~AvNA_)
wilcox.test(Bacteroidetes_Saprospirae_Saprospirales~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria_Rhizobiales~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria_Rhizobiales~AvNA_) 

plot(Proteobacteria_Gammaproteobacteria_Xanthomonadales~AvNA_)
wilcox.test(Proteobacteria_Gammaproteobacteria_Xanthomonadales~AvNA_) 

plot(Nitrospirae_Nitrospira_Nitrospirales~AvNA_)
wilcox.test(Nitrospirae_Nitrospira_Nitrospirales~AvNA_) 

plot(Proteobacteria_Deltaproteobacteria_Myxococcales~AvNA_)
wilcox.test(Proteobacteria_Deltaproteobacteria_Myxococcales~AvNA_) 

plot(Acidobacteria_Chloracidobacteria_RB41~AvNA_)
wilcox.test(Acidobacteria_Chloracidobacteria_RB41~AvNA_) 

plot(Planctomycetes_Planctomycetia_Gemmatales~AvNA_)
wilcox.test(Planctomycetes_Planctomycetia_Gemmatales~AvNA_) 

plot(Planctomycetes_Phycisphaerae_WD2101~AvNA_)
wilcox.test(Planctomycetes_Phycisphaerae_WD2101~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria_Ellin329~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria_Ellin329~AvNA_) 

plot(Acidobacteria_Acidobacteria.5_.o_~AvNA_)
wilcox.test(Acidobacteria_Acidobacteria.5_.o_~AvNA_) 

plot(Proteobacteria_Betaproteobacteria_Burkholderiales~AvNA_)
wilcox.test(Proteobacteria_Betaproteobacteria_Burkholderiales~AvNA_) 

plot(Planctomycetes_Planctomycetia_Pirellulales~AvNA_)
wilcox.test(Planctomycetes_Planctomycetia_Pirellulales~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria_Rhodospirillales~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria_Rhodospirillales~AvNA_)

plot(Actinobacteria_Thermoleophilia_Gaiellales~AvNA_)
wilcox.test(Actinobacteria_Thermoleophilia_Gaiellales~AvNA_) ##  W = 85, p-value = 0.005656

plot(Verrucomicrobia_Opitutae_Opitutales~AvNA_)
wilcox.test(Verrucomicrobia_Opitutae_Opitutales~AvNA_)

plot(Actinobacteria_Actinobacteria_Actinomycetales~AvNA_)
wilcox.test(Actinobacteria_Actinobacteria_Actinomycetales~AvNA_) ##  W = 79, p-value = 0.02505

plot(Crenarchaeota_Thaumarchaeota_Nitrososphaerales~AvNA_)
wilcox.test(Crenarchaeota_Thaumarchaeota_Nitrososphaerales~AvNA_) 

plot(Elusimicrobia_Elusimicrobia_FAC88~AvNA_)
wilcox.test(Elusimicrobia_Elusimicrobia_FAC88~AvNA_)

plot(Proteobacteria_Betaproteobacteria_o_~AvNA_)
wilcox.test(Proteobacteria_Betaproteobacteria_o_~AvNA_) 

plot(Bacteroidetes_Sphingobacteriia_Sphingobacteriales~AvNA_)
wilcox.test(Bacteroidetes_Sphingobacteriia_Sphingobacteriales~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria_Sphingomonadales~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria_Sphingomonadales~AvNA_) 

plot(Proteobacteria_Deltaproteobacteria_Desulfuromonadales~AvNA_)
wilcox.test(Proteobacteria_Deltaproteobacteria_Desulfuromonadales~AvNA_) 

plot(Proteobacteria_Alphaproteobacteria_o_~AvNA_)
wilcox.test(Proteobacteria_Alphaproteobacteria_o_~AvNA_) 


########## Site Stats ################
attach(ALLDATA.hel)

plot(MeanAC~Site_)
kruskal.test(MeanAC~Site_)
posthoc.kruskal.nemenyi.test(MeanAC~Site_)

plot(BA~Site_)
kruskal.test(BA~Site_)
posthoc.kruskal.nemenyi.test(BA~Site_)

plot(Stems~Site_)
kruskal.test(Stems~Site_)
posthoc.kruskal.nemenyi.test(Stems~Site_)

plot(Perc_Ash~Site_)
kruskal.test(Perc_Ash~Site_)
posthoc.kruskal.nemenyi.test(Perc_Ash~Site_)

plot(Perc_Maple~Site_)
kruskal.test(Perc_Maple~Site_)
posthoc.kruskal.nemenyi.test(Perc_Maple~Site_)

plot(Perc_Oak~Site_)
kruskal.test(Perc_Oak~Site_)
posthoc.kruskal.nemenyi.test(Perc_Oak~Site_)

plot(Perc_Beech~Site_)
kruskal.test(Perc_Beech~Site_)
posthoc.kruskal.nemenyi.test(Perc_Beech~Site_)

plot(Perc_Hickory~Site_)
kruskal.test(Perc_Hickory~Site_)
posthoc.kruskal.nemenyi.test(Perc_Hickory~Site_)

plot(pH~Site_)
kruskal.test(pH~Site_)
posthoc.kruskal.nemenyi.test(pH~Site_)

plot(C~Site_)
kruskal.test(C~Site_)
posthoc.kruskal.nemenyi.test(C~Site_)

plot(N~Site_)
kruskal.test(N~Site_)
posthoc.kruskal.nemenyi.test(N~Site_)

plot(CN~Site_)
kruskal.test(CN~Site_)
posthoc.kruskal.nemenyi.test(CN~Site_)

plot(Ca~Site_)
kruskal.test(Ca~Site_)
posthoc.kruskal.nemenyi.test(Ca~Site_)

plot(K~Site_)
kruskal.test(K~Site_)
posthoc.kruskal.nemenyi.test(K~Site_)

plot(Mg~Site_)
kruskal.test(Mg~Site_)
posthoc.kruskal.nemenyi.test(Mg~Site_)

plot(P~Site_)
kruskal.test(P~Site_)
posthoc.kruskal.nemenyi.test(P~Site_)

plot(Al~Site_)
kruskal.test(Al~Site_)
posthoc.kruskal.nemenyi.test(Al~Site_)

plot(B~Site_)
kruskal.test(B~Site_)
posthoc.kruskal.nemenyi.test(B~Site_)

plot(Cu~Site_)
kruskal.test(Cu~Site_)
posthoc.kruskal.nemenyi.test(Cu~Site_)

plot(Fe~Site_)
kruskal.test(Fe~Site_)
posthoc.kruskal.nemenyi.test(Fe~Site_)

plot(Mn~Site_)
kruskal.test(Mn~Site_)
posthoc.kruskal.nemenyi.test(Mn~Site_)

plot(Na~Site_)
kruskal.test(Na~Site_)
posthoc.kruskal.nemenyi.test(Na~Site_)

plot(S~Site_)
kruskal.test(S~Site_)
posthoc.kruskal.nemenyi.test(S~Site_)

plot(Zn~Site_)
kruskal.test(Zn~Site_)
posthoc.kruskal.nemenyi.test(Zn~Site_)

########## Site Wilcox test (only for "healthy" sites analysis)

plot(MeanAC~Site_)
bartlett.test(MeanAC~Site_)  
shapiro.test(MeanAC)
wilcox.test(MeanAC~Site_)

plot(BA~Site_)
bartlett.test(BA~Site_)  
shapiro.test(BA)
wilcox.test(BA~Site_) 

plot(Stems~Site_)
bartlett.test(Stems~Site_)  
shapiro.test(Stems)  
wilcox.test(Stems~Site_)

plot(Perc_Ash~Site_)
bartlett.test(Perc_Ash~Site_)  
shapiro.test(Perc_Ash)  
wilcox.test(Perc_Ash~Site_)

plot(Perc_Maple~Site_)
bartlett.test(Perc_Maple~Site_)  
shapiro.test(Perc_Maple)  
wilcox.test(Perc_Maple~Site_)

plot(Perc_Oak~Site_)
bartlett.test(Perc_Oak~Site_)  
shapiro.test(Perc_Oak)  
wilcox.test(Perc_Oak~Site_)

plot(Perc_Beech~Site_)
bartlett.test(Perc_Beech~Site_)  
shapiro.test(Perc_Beech)  
wilcox.test(Perc_Beech~Site_)

plot(Perc_Hickory~Site_)
bartlett.test(Perc_Hickory~Site_)  
shapiro.test(Perc_Hickory)  
wilcox.test(Perc_Hickory~Site_)

plot(pH~Site_)
bartlett.test(pH~Site_)  
shapiro.test(pH) 
wilcox.test(pH~Site_)

plot(C~Site_)
bartlett.test(C~Site_)  
shapiro.test(C)
wilcox.test(C~Site_)

plot(N~Site_)
bartlett.test(N~Site_)  
shapiro.test(N)
wilcox.test(N~Site_) 

plot(CN~Site_)
bartlett.test(CN~Site_)  
shapiro.test(CN)
wilcox.test(CN~Site_) 

plot(Ca~Site_)
bartlett.test(Ca~Site_)  
shapiro.test(Ca)
wilcox.test(Ca~Site_) 

plot(K~Site_)
bartlett.test(K~Site_)  
shapiro.test(K)
wilcox.test(K~Site_) 

plot(P~Site_)
bartlett.test(P~Site_)  
shapiro.test(P)
wilcox.test(P~Site_) 

plot(Mg~Site_) 
bartlett.test(Mg~Site_)  
shapiro.test(Mg)
wilcox.test(Mg~Site_)

plot(Al~Site_)
bartlett.test(Al~Site_)  
shapiro.test(Al)
wilcox.test(Al~Site_) 

plot(B~Site_)
bartlett.test(B~Site_)  
shapiro.test(B)
wilcox.test(B~Site_) 

plot(Cu~Site_)
bartlett.test(Cu~Site_)  
shapiro.test(Cu)
wilcox.test(Cu~Site_) 

plot(Fe~Site_)
bartlett.test(Fe~Site_)  
shapiro.test(Fe)
wilcox.test(Fe~Site_) 

plot(Mn~Site_)
bartlett.test(Mn~Site_)  
shapiro.test(Mn)
wilcox.test(Mn~Site_) 

plot(Na~Site_)
bartlett.test(Na~Site_)  
shapiro.test(Na)
wilcox.test(Na~Site_) 

plot(S~Site_)
bartlett.test(S~Site_)  
shapiro.test(S)
wilcox.test(S~Site_)

plot(Zn~Site_)
bartlett.test(Zn~Site_)  
shapiro.test(Zn)
wilcox.test(Zn~Site_)

##############  Alpha Diversity  #########

alpha_div <- read.delim("Alpha_div.txt")

##  Remove sites with AC>3
alpha_div_AC3 <- alpha_div[c(1:10),]

attach(alpha_div)
#attach(alpha_div_AC3)
wilcox.test(Bacteria~AvNA)

kruskal.test(Bacteria~Site)
posthoc.kruskal.nemenyi.test(Bacteria~Site)
wilcox.test(Bacteria~Site)

wilcox.test(Tree~AvNA)

kruskal.test(Tree~Site)
posthoc.kruskal.nemenyi.test(Tree~Site)
wilcox.test(Tree~Site)

kruskal.test(Tree~Plot)
posthoc.kruskal.nemenyi.test(Tree~Plot)

BacAlpha_dm <- dist(Bacteria)
mantel(bacBray.hel,BacAlpha_dm, permutations = 99999)

TreeAlpha_dm <- dist(Tree)
mantel(bacBray.hel,TreeAlpha_dm, permutations = 99999)

############## Ash only ##################

dfbac_ash <- data.frame(ash[,29:72])
dfbac_ash.hel<-decostand(dfbac_ash,"hellinger")
bacBray_ash.hel <- vegdist(dfbac_ash.hel)

dfenv_ash <- data.frame(ash[,2:28])

ash.hel <- cbind(dfenv_ash,dfbac_ash.hel)

attach(ash.hel)
#anova(betadisper(bacBray_ash.hel,MeanAC))
#adonis(bacBray_ash.hel~MeanAC, permutations = 99999))  

AC_dm_ash <- dist(dfenv_ash$MeanAC)
mantel(bacBray_ash.hel,AC_dm_ash, permutations = 99999)

PercAsh_dm_ash <- dist(dfenv_ash$Perc_Ash)
mantel(bacBray_ash.hel,PercAsh_dm_ash, permutations = 99999)

plot(MeanAC~Site_)
kruskal.test(MeanAC~Site_)
posthoc.kruskal.nemenyi.test(MeanAC~Site_)
wilcox.test(MeanAC~Site_)  # For "healthy" site analysis

plot(Perc_Ash~Site_)
kruskal.test(Perc_Ash~Site_)



## Effects of all soil variables on bacterial community structure

mantel(bacBray.hel,soilEuclid, permutations = 99999)

## Effects of individual variables on bacterial community structure
attach(ALLDATA.hel)
AC_dm <- dist(dfenv1$MeanAC)
mantel(bacBray.hel,AC_dm, permutations = 99999)
anova(betadisper(bacBray.hel,MeanAC))
(adonis(bacBray.hel~MeanAC, permutations = 99999))

Stems_dm <- dist(dfenv1$Stems)
mantel(bacBray.hel,Stems_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Stems))
(adonis(bacBray.hel~Stems, permutations = 99999))

BA_dm <- dist(dfenv1$BA)
mantel(bacBray.hel,BA_dm, permutations = 99999)
anova(betadisper(bacBray.hel,BA))
(adonis(bacBray.hel~BA, permutations = 99999))

Ash_dm <- dist(dfenv1$Perc_Ash)
mantel(bacBray.hel,Ash_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Perc_Ash))
(adonis(bacBray.hel~Perc_Ash, permutations = 99999))

Maple_dm <- dist(dfenv1$Perc_Maple)
mantel(bacBray.hel,Maple_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Perc_Maple))
(adonis(bacBray.hel~Perc_Maple, permutations = 99999))

Oak_dm <- dist(dfenv1$Perc_Oak)
mantel(bacBray.hel,Oak_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Perc_Oak))
(adonis(bacBray.hel~Perc_Oak, permutations = 99999))

Beech_dm <- dist(dfenv1$Perc_Beech)
mantel(bacBray.hel,Beech_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Perc_Beech))
(adonis(bacBray.hel~Perc_Beech, permutations = 99999))

Hickory_dm <- dist(dfenv1$Perc_Hickory)
mantel(bacBray.hel,Hickory_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Perc_Hickory))
(adonis(bacBray.hel~Perc_Hickory, permutations = 99999))

pH_dm <- dist(dfenv1$pH)
mantel(bacBray.hel,pH_dm, permutations = 99999)
anova(betadisper(bacBray.hel,pH))
(adonis(bacBray.hel~pH, permutations = 99999))

C_dm <- dist(dfenv1$C)
mantel(bacBray.hel,C_dm, permutations = 99999)
anova(betadisper(bacBray.hel,C))
(adonis(bacBray.hel~C, permutations = 99999))

N_dm <- dist(dfenv1$N)
mantel(bacBray.hel,N_dm, permutations = 99999)
anova(betadisper(bacBray.hel,N))
(adonis(bacBray.hel~N, permutations = 99999))

CN_dm <- dist(dfenv1$CN)
mantel(bacBray.hel,CN_dm, permutations = 99999)
anova(betadisper(bacBray.hel,CN))
(adonis(bacBray.hel~CN, permutations = 99999))

Ca_dm <- dist(dfenv1$Ca)
mantel(bacBray.hel,Ca_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Ca))
(adonis(bacBray.hel~Ca, permutations = 99999))

K_dm <- dist(dfenv1$K)
mantel(bacBray.hel,K_dm, permutations = 99999)
anova(betadisper(bacBray.hel,K))
(adonis(bacBray.hel~K, permutations = 99999))

Mg_dm <- dist(dfenv1$Mg)
mantel(bacBray.hel,Mg_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Mg))
(adonis(bacBray.hel~Mg, permutations = 99999))

P_dm <- dist(dfenv1$P)
mantel(bacBray.hel,P_dm, permutations = 99999)
anova(betadisper(bacBray.hel,P))
(adonis(bacBray.hel~P, permutations = 99999))

Al_dm <- dist(dfenv1$Al)
mantel(bacBray.hel,Al_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Al))
(adonis(bacBray.hel~Al, permutations = 99999))

B_dm <- dist(dfenv1$B)
mantel(bacBray.hel,B_dm, permutations = 99999)
anova(betadisper(bacBray.hel,B))
(adonis(bacBray.hel~B, permutations = 99999))

Cu_dm <- dist(dfenv1$Cu)
mantel(bacBray.hel,Cu_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Cu))
(adonis(bacBray.hel~Cu, permutations = 99999))

Fe_dm <- dist(dfenv1$Fe)
mantel(bacBray.hel,Fe_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Fe))
(adonis(bacBray.hel~Fe, permutations = 99999))

Mn_dm <- dist(dfenv1$Mn)
mantel(bacBray.hel,Mn_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Mn))
(adonis(bacBray.hel~Mn, permutations = 99999))

Na_dm <- dist(dfenv1$Na)
mantel(bacBray.hel,Na_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Na))
(adonis(bacBray.hel~Na, permutations = 99999))

S_dm <- dist(dfenv1$S)
mantel(bacBray.hel,S_dm, permutations = 99999)
anova(betadisper(bacBray.hel,S))
(adonis(bacBray.hel~S, permutations = 99999))

Zn_dm <- dist(dfenv1$Zn)
mantel(bacBray.hel,Zn_dm, permutations = 99999)
anova(betadisper(bacBray.hel,Zn))
(adonis(bacBray.hel~Zn, permutations = 99999))


################# Bacterial phyla vs AC ##############
attach(ash.hel)

plot(Acidobacteria~MeanAC)
abline(lm(Acidobacteria~MeanAC)) 
summary(lm(Acidobacteria~MeanAC))
cor.test(Acidobacteria,MeanAC)

plot(Verrucomicrobia~MeanAC)
abline(lm(Verrucomicrobia~MeanAC)) 
summary(lm(Verrucomicrobia~MeanAC))

plot(Proteobacteria~MeanAC)
abline(lm(Proteobacteria~MeanAC)) 
summary(lm(Proteobacteria~MeanAC))

plot(Bacteroidetes~MeanAC)
abline(lm(Bacteroidetes~MeanAC)) 
summary(lm(Bacteroidetes~MeanAC))

plot(Planctomycetes~MeanAC)
abline(lm(Planctomycetes~MeanAC)) 
summary(lm(Planctomycetes~MeanAC))

plot(Nitrospirae~MeanAC)
abline(lm(Nitrospirae~MeanAC)) 
summary(lm(Nitrospirae~MeanAC))

plot(Actinobacteria~MeanAC)
abline(lm(Actinobacteria~MeanAC)) 
summary(lm(Actinobacteria~MeanAC))

plot(Elusimicrobia~MeanAC)
abline(lm(Elusimicrobia~MeanAC)) 
summary(lm(Elusimicrobia~MeanAC))

plot(Crenarchaeota~MeanAC)
abline(lm(Crenarchaeota~MeanAC)) 
summary(lm(Crenarchaeota~MeanAC))

plot(Chloroflexi~MeanAC)
abline(lm(Chloroflexi~MeanAC)) 
summary(lm(Chloroflexi~MeanAC))



##########################################################################
                              #FIGURES

############################  Figure 2 - NMDS plot #################

#### Import qiime data
## Original files - "normalized_otus.biom","Ohio_16S_map.txt"

norm_biom <- import_biom("normalized_otus.biom", treefilename = "rep_set.tre", refseqfilename = "new_refseqs.fna", parseFunction = parse_taxonomy_greengenes)
map <- import_qiime_sample_data("Ohio_16S_map.txt")

data <- merge_phyloseq(norm_biom, map)

data
sample_data(data)
head(tax_table(data))

# Ordinate NMDS using Bray, use stress plot to find the best dissimilarit/distance
nmds.bray <- ordinate(data,"NMDS","bray") 
stressplot(nmds.bray)
nmds.bray
as.data.frame(nmds.bray$points)

## Make Env dataframe
sam <- sample_data(data)
environ<-data.frame(sample_data(data)[,4:23])
str(environ)

## Make dataframe with AvNA and site data
sites <- data.frame(scores(nmds.bray, choices=c(1,2),display = c("sites"))) #dataframe of species scores for plotting
head(sites)
sites$Ash_vs_NonAsh <- sample_data(data)$Ash_vs_NonAsh #otherwise factor doesn't drop unused levels and it will throw an error
sites$Site <- sample_data(data)$Site

#envfit
nmds.bray.envfit <- envfit(as.data.frame(nmds.bray$points), 
                           env = environ,na.rm=TRUE, perm = 999) #standard envfit
plot(nmds.bray)
plot(nmds.bray.envfit,p=0.05)

######  Data for ellipses
# function for ellipsess - just run this, is used later
#taken from the excellent stackoverflow Q+A: http://stackoverflow.com/questions/13794419/plotting-ordiellipse-function-from-vegan-package-onto-nmds-plot-created-in-ggplo
veganCovEllipse <- function (cov, center = c(0, 0), scale = 1, npoints = 100)
{
  theta <- (0:npoints) * 2 * pi/npoints
  Circle <- cbind(cos(theta), sin(theta))
  t(center + scale * t(Circle %*% chol(cov)))
}

# data for ellipse, ash vs nonash
df_ell.AvNA <- data.frame() #sets up a data frame before running the function.
for(g in levels(sites$Ash_vs_NonAsh)){
  df_ell.AvNA <- rbind(df_ell.AvNA, cbind(as.data.frame(with(sites [sites$Ash_vs_NonAsh==g,],
                                                             veganCovEllipse(cov.wt(cbind(NMDS1,NMDS2),wt=rep(1/length(NMDS1),length(NMDS1)))$cov,center=c(mean(NMDS1),mean(NMDS2)))))
                                          ,Ash_vs_NonAsh=g))
}

# data for labelling the ellipse
NMDS.mean=aggregate(sites[,c("NMDS1", "NMDS2")],
                    list(group = sites$Ash_vs_NonAsh), mean)

## Finally plotting

#  Ash vs NonAsh NMDS plot
nmds2 <- ggplot(data = sites, aes(x = NMDS1, y = NMDS2, col=Ash_vs_NonAsh)) + #sets up the plot. brackets around the entire thing to make it draw automatically
  geom_point(colour="black", size = 8, aes(shape=Site),show.legend = TRUE) +
  geom_point(size=7, aes(shape=Site, col=Ash_vs_NonAsh),show.legend = TRUE) +
  scale_shape_manual(values=c(15, 16, 17, 18)) +
  scale_colour_manual(values=c("#8FADCF", "#F5AE51")) +
  geom_path(data = df_ell.AvNA, aes(x = NMDS1, y = NMDS2, group = Ash_vs_NonAsh)) + #this is the ellipse, seperate ones by type. If you didn't change the "alpha" (the shade) then you need to keep the "group  annotate("text",x = -0.70,y = 0.5,label="Filter",size=6) + #labels for the centroids - I haven't used this since we have a legend. but you could also dithc the legend, but plot will get v messy
  theme_bw() +
  theme(axis.title.y = element_text(size=20),
        axis.title.x = element_text(size=20),
        axis.text = element_text(size=16),
        legend.key.size = unit(0.5, "in"),
        legend.text = element_text(size = 16),
        legend.title = element_blank()) 
nmds2

#ggsave("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/Figure2_NMDS.eps", units="in", width=12, height=9, dpi=1200)


###################  Figures 2, S1, and S2 - Boxplots ########################

L2.hel <- read.delim("Hel_L2_boxplot.txt")
L2.hel_long <- melt(L2.hel, variable.name = "Phyla", value.name = "Abundance")

L3.hel <- read.delim("Hel_L3_boxplot.txt")
L3.hel_long <- melt(L3.hel, variable.name = "Phyla", value.name = "Abundance")

L4.hel <- read.delim("Hel_L4_boxplot.txt")
L4.hel_long <- melt(L4.hel, variable.name = "Phyla", value.name = "Abundance")

attach(L2.hel_long)

ggplot(L2.hel_long, aes(x=Phyla, y=Abundance, fill=AvNA_)) +
  geom_boxplot(width=.75, position=position_dodge(width=0.75)) +
  theme_bw() +
  scale_y_sqrt() +
  scale_fill_manual(values=c("#8FADCF", "#F5AE51")) +
  labs(x="Phylum", y=expression(sqrt("Relative Abundance (%)"))) +
  theme(axis.text.y = element_text(size=20)) +
  theme(legend.title=element_blank(),legend.text=element_text(size=20), legend.key.size=unit(2,"cm")) +
  theme(axis.title.y = element_text(size=20)) +
  theme(axis.title.x = element_blank()) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size=23))

#ggsave("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/Figure3_Phyla.eps", units="in", width=18, height=11, dpi=1200)

####  Boxpots at Class and Order level

attach(L3.hel_long)

ggplot(L3.hel_long, aes(x=Phyla, y=Abundance, fill=AvNA_)) +
  geom_boxplot(width=.75, position=position_dodge(width=0.75)) +
  theme_bw() +
  scale_y_sqrt() +
  scale_fill_manual(values=c("#8FADCF", "#F5AE51")) +
  labs(x="Phylum", y=expression(sqrt("Relative Abundance (%)"))) +
  theme(axis.text.y = element_text(size=20)) +
  theme(legend.title=element_blank(),legend.text=element_text(size=20), legend.key.size=unit(2,"cm")) +
  theme(axis.title.y = element_text(size=20)) +
  theme(axis.title.x = element_blank()) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size=18)) +
  theme(plot.margin = unit(c(1,1,1,4), "cm"))

#ggsave("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/FigureS1_Classes.eps", units="in", width=18, height=11, dpi=1200)

#### Level 4

attach(L4.hel_long)

ggplot(L4.hel_long, aes(x=Phyla, y=Abundance, fill=AvNA_)) +
  geom_boxplot(width=.75, position=position_dodge(width=0.75)) +
  theme_bw() +
  scale_y_sqrt() +
  scale_fill_manual(values=c("#8FADCF", "#F5AE51")) +
  labs(x="Phylum", y=expression(sqrt("Relative Abundance (%)"))) +
  theme(axis.text.y = element_text(size=25)) +
  theme(legend.title=element_blank(),legend.text=element_text(size=25), legend.key.size=unit(2,"cm")) +
  theme(axis.title.y = element_text(size=25)) +
  theme(axis.title.x = element_blank()) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1, size=22)) +
  theme(plot.margin = unit(c(1,1,1,10), "cm"))

#ggsave("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/FigureS2_Orders.eps", units="in", width=30, height=16, dpi=1200)



#####################  Figure 4 - Bacterial abundance vs. Mean AC   ######
attach(ash.hel)
### Facet wrap 
AC_Bac <- ash.hel[, c(2,28:37)]

### AC_Bac <- read.delim("AC_Bac.txt")
AC_Bac$MeanAC <- factor(AC_Bac$MeanAC)
levels(AC_Bac$MeanAC)
AC_Bac_long <- melt(AC_Bac, variable.name = "Phyla", value.name = "Abundance")
AC_Bac_long$MeanAC <- as.numeric(levels(AC_Bac_long$MeanAC))[AC_Bac_long$MeanAC]

###  Facet grid!!
ggplot(AC_Bac_long,aes(x=MeanAC, y=Abundance, color=Phyla)) +
  geom_point(size=2) +
  geom_smooth(size = 0.25, method="lm", formula = y ~ x, se = F) +
  facet_wrap( ~ Phyla, ncol=5) +
  theme_bw() +
  scale_y_sqrt() +
  theme(legend.position="none") +
  labs(x="Mean AC", y=expression(sqrt("Relative Abundance (%)"))) #+
#theme(panel.spacing.y = unit(4, "lines"))

#ggsave("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/AC_Bac.eps", units="in", width=9, height=4, dpi=1200)

##  Another way for just 1 graph!
ggplot(AC_Bac_long,aes(x=MeanAC, y=Abundance, color=Phyla)) +
  geom_point(size=2) +
  geom_smooth(size = 0.25, method="lm", formula = y ~ x, se = F) +
  theme_bw() +
  labs(x="Mean AC", y=expression(sqrt("Relative Abundance (%)"))) +
  theme(legend.title=element_blank())


##################### Figure 6 - Correlations ##########################

## Genes_Bac figure
names(dfgenes)
dfgenes_reorder <- dfgenes[c("Starch.and.sucrose.metabolism",
                             "Amino.sugar.and.nucleotide.sugar.metabolism", 
                             "Galactose.metabolism",
                             "Pentose.and.glucuronate.interconversions",
                             "Pyruvate.metabolism",
                             "Methane.metabolism",
                             "Carbon.fixation.pathways.in.prokaryotes",
                             "Butanoate.metabolism",
                             "Oxidative.phosphorylation",
                             "Citrate.cycle..TCA.cycle.",
                             "Glycolysis...Gluconeogenesis",
                             "Pentose.phosphate.pathway",
                             "Inositol.phosphate.metabolism",
                             "Sulfur.metabolism",
                             "Carbon.fixation.in.photosynthetic.organisms",
                             "Ascorbate.and.aldarate.metabolism",
                             "Propanoate.metabolism",
                             "Glyoxylate.and.dicarboxylate.metabolism",
                             "Photosynthesis",
                             "Fructose.and.mannose.metabolism",
                             "Photosynthesis.proteins",
                             "Nitrogen.metabolism",
                             "C5.Branched.dibasic.acid.metabolism",
                             "Photosynthesis...antenna.proteins")]
dfgenes_noPunct <- rename(dfgenes_reorder,c("Amino.sugar.and.nucleotide.sugar.metabolism"="Amino sugar & nucleotide sugar metabolism", 
                                    "Ascorbate.and.aldarate.metabolism"="Ascorbate & aldarate metabolism",
                                    "Butanoate.metabolism"="Butanoate metabolism",
                                    "C5.Branched.dibasic.acid.metabolism"="C5-Branched dibasic acid metabolism",
                                    "Citrate.cycle..TCA.cycle."="Citrate cycle (TCA cycle)", 
                                    "Fructose.and.mannose.metabolism"="Fructose & mannose metabolism",
                                    "Galactose.metabolism"="Galactose metabolism", 
                                    "Glycolysis...Gluconeogenesis"="Glycolysis/Gluconeogenesis", 
                                    "Glyoxylate.and.dicarboxylate.metabolism"="Glyoxylate & dicarboxylate metabolism", 
                                    "Inositol.phosphate.metabolism"="Inositol phosphate metabolism", 
                                    "Pentose.and.glucuronate.interconversions"="Pentose & glucuronate interconversions", 
                                    "Pentose.phosphate.pathway"="Pentose phosphate pathway", 
                                    "Propanoate.metabolism"="Propanoate metabolism", 
                                    "Pyruvate.metabolism"="Pyruvate metabolism", 
                                    "Starch.and.sucrose.metabolism"="Starch & sucrose metabolism", 
                                    "Carbon.fixation.in.photosynthetic.organisms"="C-fixation in photosynthetic organisms", 
                                    "Carbon.fixation.pathways.in.prokaryotes"="C-fixation pathways in prokaryotes", 
                                    "Methane.metabolism"="Methane metabolism", 
                                    "Nitrogen.metabolism"="Nitrogen metabolism", 
                                    "Oxidative.phosphorylation"="Oxidative phosphorylation", 
                                    "Photosynthesis"="Photosynthesis", 
                                    "Photosynthesis...antenna.proteins"="Photosynthesis-antenna proteins", 
                                    "Photosynthesis.proteins"="Photosynthesis proteins", 
                                    "Sulfur.metabolism"="Sulfur metabolism"))


Bac10_genes_cor <- cor(dfgenes_noPunct,dfbac10.hel)

options(max.print=1000000)
genes_bac10 <- cbind(dfgenes,dfbac10.hel)
rcorr(as.matrix(genes_bac10))

## Make correlation matrix
pdf("~/Box Sync/Work/Professional/Writing/Manuscipts/Ohio_Ash/Forests/Submission/Figures/Figure5_Correlations.eps", width = 7, height = 7)
par(xpd=TRUE)
corrplot(Bac10_genes_cor, tl.col="black", tl.cex=0.8, cl.cex=0.8, cl.align.text="l",mar = c(0, 0, 0.5, 0), tl.srt = 45)
dev.off()

